Resources

Struct Resources 

pub struct Resources<'a> { /* private fields */ }
Resources filesystem.

Implementations

Source

impl<'a> Resources<'a>

pub fn find_resource(&self, path: &[Name<'_>; 2]) -> Result<&'a [u8], FindError>

Finds a resource by its type and name.

pub fn find_resources( &self, path: &[Name<'_>; 2], ) -> Result<Directory<'a>, FindError>

Finds the language directory for a resource with given type and name.

pub fn find_resource_ex( &self, path: &[Name<'_>; 3], ) -> Result<&'a [u8], FindError>

Finds the resource with specified type, name and language.

pub fn version_info(&self) -> Result<VersionInfo<'a>, FindError>

Gets the Version Information.

pub fn manifest(&self) -> Result<&'a str, FindError>

Gets the Application Manifest.

pub fn icons( &self, ) -> impl 'a + Iterator<Item = Result<(Name<'a>, GroupIcon<'a>), FindError>> + Clone

Gets the icons.

pub fn cursors( &self, ) -> impl 'a + Iterator<Item = Result<(Name<'a>, GroupCursor<'a>), FindError>> + Clone

Gets the cursors.

Source

impl<'a> Resources<'a>

pub fn find<P: AsRef<Path> + ?Sized>( &self, path: &P, ) -> Result<Entry<'a>, FindError>

Finds a file or directory by its path.

pub fn find_data<P: AsRef<Path> + ?Sized>( &self, path: &P, ) -> Result<DataEntry<'a>, FindError>

Finds a file by its path.

pub fn find_dir<P: AsRef<Path> + ?Sized>( &self, path: &P, ) -> Result<Directory<'a>, FindError>

Finds a directory by its path.

Source

impl<'a> Resources<'a>

pub fn new(section: &'a [u8], dir: &'a IMAGE_DATA_DIRECTORY) -> Resources<'a>

Parse the bytes as PE resources.

No validation or integrity checking is done ahead of time.

pub fn root(&self) -> Result<Directory<'a>>

Gets the root directory.

pub fn fsck(&self) -> Result<()>

Filesystem consistency check.

Simply walks the filesystem checking all references are valid.