Security

Struct Security 

pub struct Security<'a> { /* private fields */ }
Security Directory.

For more information see the module-level documentation.

Implementations

Source

impl<'a> Security<'a>

pub fn image(&self) -> &'a WIN_CERTIFICATE

Returns the underlying security directory image.

pub fn certificate_type(&self) -> u16

pub fn certificate_data(&self) -> &'a [u8]

Gets the raw certificate data bytes.

The interpretation of this data depends the type of the certificate. No further introspection is provided.

External tools such as OpenSSL can be used to further disect and analyze this data. Eg. for WIN_CERT_TYPE_PKCS_SIGNED_DATA the following can be used to decode the bytes:

openssl pkcs7 -inform DER -print_certs -text -in pe_certificate