pub struct Security<'a> { /* private fields */ }Expand description
Security Directory.
For more information see the module-level documentation.
Implementations
Sourceimpl<'a> Security<'a>
impl<'a> Security<'a>
Sourcepub fn image(&self) -> &'a WIN_CERTIFICATE
pub fn image(&self) -> &'a WIN_CERTIFICATE
Returns the underlying security directory image.
Sourcepub fn certificate_type(&self) -> u16
pub fn certificate_type(&self) -> u16
Gets the type of the certificate.
List of known certificate types:
Sourcepub fn certificate_data(&self) -> &'a [u8] ⓘ
pub fn certificate_data(&self) -> &'a [u8] ⓘ
Gets the raw certificate data bytes.
The interpretation of this data depends the type of the certificate. No further introspection is provided.
External tools such as OpenSSL can be used to further disect and analyze this data.
Eg. for WIN_CERT_TYPE_PKCS_SIGNED_DATA the following can be used to decode the bytes:
openssl pkcs7 -inform DER -print_certs -text -in pe_certificateTrait Implementations
impl<'a> Copy for Security<'a>